#
# spec file for package ffmpeg-3
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Create proper conflicts to make sure we require all from one version
# p:   Conflict string, eg if you need them all for requires instead
#      Default value Conflicts:
# c:   copmare string ie "<" or ">=", must be defined
# v:   version string ie. "< 42.3.4" or ">= 15.0.2.1", must be defined
%define devel_conflicts(p:c:v:) \
%define preamble_string %{-p:%{-p*}}%{!-p:Conflicts:} \
%define comparator %{-c:%{-c*}}%{!-c:%{error:Comparator not defined}} \
%define conflicts_version %{-v:%{-v*}}%{!-v:%{error:Version not defined}} \
\
%{preamble_string} libavcodec-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavdevice-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavfilter-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavformat-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavresample-devel %{comparator} %{conflicts_version} \
%{preamble_string} libavutil-devel %{comparator} %{conflicts_version} \
%{preamble_string} libpostproc-devel %{comparator} %{conflicts_version} \
%{preamble_string} libswresample-devel %{comparator} %{conflicts_version} \
%{preamble_string} libswscale-devel %{comparator} %{conflicts_version} \
%{preamble_string} ffmpeg-private-devel %{comparator} %{conflicts_version} \
%{nil}

%if 0%{?BUILD_ORIG}
%bcond_without nvidia
%else
%bcond_with    nvidia
%endif
%bcond_with    fdk_aac
%bcond_with    librtmp
%bcond_with    vo_aacenc
%bcond_with    x264
%bcond_with    x265
%bcond_with    xvid
%bcond_with    opencore

# Full build or just support package on older codestream
%if 0%{?suse_version} <= 1500
%bcond_without full_build
%else
%bcond_with full_build
%endif

%if 0%{?suse_version} >= 1500
%bcond_without zimg
%else
%bcond_with zimg
%endif

%if 0%{?suse_version} > 1500
%bcond_without vidstab
%else
%bcond_with vidstab
%endif

%define _name ffmpeg
%define _major_version 3
%define _major_expected 4
Name:           ffmpeg-3
Version:        3.4.4
Release:        lp150.10.7
Summary:        Library for working with various multimedia formats
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            https://ffmpeg.org/

#Freshcode-URL:    http://freshcode.club/projects/ffmpeg
#Git-Clone:     git://source.ffmpeg.org/ffmpeg
Source:         https://www.ffmpeg.org/releases/%_name-%version.tar.xz
Source2:        https://www.ffmpeg.org/releases/%_name-%version.tar.xz.asc
Source3:        ffmpeg-rpmlintrc
Source4:        enable_decoders
Source5:        enable_encoders
Source99:       baselibs.conf
Patch1:         ffmpeg-libcdio_cdda-pkgconfig.patch
Patch2:         ffmpeg-arm6l.diff
Patch3:         ffmpeg-new-coder-errors.diff
Patch4:         ffmpeg-codec-choice.diff
Patch5:         cve-2017-17555.diff
Patch6:         0001-opusenc-psy-disable-stereo-searches.patch
BuildRequires:  ladspa-devel
BuildRequires:  libgsm-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  nasm
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(celt) >= 0.11.0
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(fontconfig) >= 2.4.2
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi) >= 0.19.0
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libbluray)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_paranoia)
BuildRequires:  pkgconfig(libdc1394-2)
BuildRequires:  pkgconfig(liboil-0.3) >= 0.3.15
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libraw1394)
BuildRequires:  pkgconfig(libva) >= 0.35.0
BuildRequires:  pkgconfig(libwebp) >= 0.4
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(theora) >= 1.1
BuildRequires:  pkgconfig(twolame)
BuildRequires:  pkgconfig(vdpau)
%if %{with vidstab}
BuildRequires:  pkgconfig(vidstab) >= 0.98
%endif
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vpx) >= 1.3.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-shm)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
%if %{with zimg}
BuildRequires:  pkgconfig(zimg)
%endif
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(zvbi-0.2)
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(libopenjpeg)
BuildRequires:  pkgconfig(sdl2)
%endif
%if 0%{?BUILD_ORIG}
%if %{with fdk_aac}
BuildRequires:  pkgconfig(fdk-aac)
%endif
%if %{with librtmp}
BuildRequires:  pkgconfig(librtmp)
%endif
%if %{with xvid}
BuildRequires:  libxvidcore-devel
%endif
%if %{with opencore}
BuildRequires:  pkgconfig(opencore-amrnb)
%endif
%if %{with x264}
BuildRequires:  pkgconfig(x264)
%endif
%if %{with x265}
BuildRequires:  pkgconfig(x265)
%endif
%endif
Provides:       ffmpeg-tools = %{version}
Obsoletes:      ffmpeg-tools < %{version}
Provides:       ffmpeg = %version
Obsoletes:      ffmpeg < %version
Requires:       libavcodec57 = %version-%release
Requires:       libavdevice57 = %version-%release
Requires:       libavfilter6 = %version-%release
Requires:       libavformat57 = %version-%release
Requires:       libavresample3 = %version-%release
Requires:       libavutil55 = %version-%release
Requires:       libpostproc54 = %version-%release
Requires:       libswresample2 = %version-%release
Requires:       libswscale4 = %version-%release

%description
FFmpeg is a multimedia framework, able to decode, encode,
transcode, mux, demux, stream, filter and play several formats
that humans and machines have created.
%if !0%{?BUILD_ORIG}

This build of ffmpeg is limited in the number of codecs supported.
%endif

%package -n libavcodec57
Summary:        FFmpeg codec library
# For mozillas
Group:          System/Libraries
Requires:       libavutil55 = %version-%release
Requires:       libswresample2 = %version-%release
Provides:       libavcodec = %version-%release
%if 0%{?BUILD_ORIG}
Provides:       libavcodec-full = %version-%release
# This can be required by packages likes vlc-codecs - following the shlib name to not get random lib providers
Provides:       libavcodec57(unrestricted)
%endif

%description -n libavcodec57
The libavcodec library provides a generic encoding/decoding framework
and contains multiple decoders and encoders for audio, video and
subtitle streams, and several bitstream filters.
%if !0%{?BUILD_ORIG}

This build of ffmpeg is limited in the number of codecs supported.
%endif

%package libavcodec-devel
Summary:        Development files for FFmpeg's codec library
Group:          Development/Libraries/C and C++
Provides:       libavcodec-devel = %version-%release
Obsoletes:      libavcodec-devel < %version-%release
Requires:       %{name}-libavresample-devel = %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libavcodec57 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavcodec-devel
The libavcodec library provides a generic encoding/decoding framework
and contains multiple decoders and encoders for audio, video and
subtitle streams, and several bitstream filters.

This subpackage contains the headers for FFmpeg libavcodec.

%package -n libavdevice57
Summary:        FFmpeg device library
Group:          System/Libraries
Requires:       libavcodec57 = %version-%release
Requires:       libavfilter6 = %version-%release
Requires:       libavformat57 = %version-%release
Requires:       libavutil55 = %version-%release

%description -n libavdevice57
The libavdevice library provides a generic framework for grabbing from
and rendering to many common multimedia input/output devices, and
supports several input and output devices, including Video4Linux2, VfW,
DShow, and ALSA.

%package libavdevice-devel
Summary:        Development files for FFmpeg's device library
Group:          Development/Libraries/C and C++
Provides:       ffmpeg-devel = %version-%release
Conflicts:      ffmpeg-devel
Provides:       ffmpeg3-devel = %version-%release
Obsoletes:      ffmpeg3-devel < %version-%release
Provides:       libavdevice-devel = %version-%release
Obsoletes:      libavdevice-devel < %version-%release
Requires:       %{name}-libavcodec-devel = %version-%release
Requires:       %{name}-libavfilter-devel = %version-%release
Requires:       %{name}-libavformat-devel = %version-%release
Requires:       %{name}-libavresample-devel = %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       %{name}-libpostproc-devel = %version-%release
Requires:       %{name}-libswresample-devel = %version-%release
Requires:       %{name}-libswscale-devel = %version-%release
Requires:       libavdevice57 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavdevice-devel
The libavdevice library provides a generic framework for grabbing from
and rendering to many common multimedia input/output devices, and
supports several input and output devices, including Video4Linux2, VfW,
DShow, and ALSA.

This subpackage contains the headers for FFmpeg libavcodec.

%package -n libavfilter6
Summary:        FFmpeg audio and video filtering library
Group:          System/Libraries
Requires:       libavcodec57 = %version-%release
Requires:       libavformat57 = %version-%release
Requires:       libavresample3 = %version-%release
Requires:       libavutil55 = %version-%release
Requires:       libpostproc54 = %version-%release
Requires:       libswresample2 = %version-%release
Requires:       libswscale4 = %version-%release

%description -n libavfilter6
The libavfilter library provides a generic audio/video filtering
framework containing several filters, sources and sinks.

%package libavfilter-devel
Summary:        Development files for FFmpeg's audio/video filter library
Group:          Development/Libraries/C and C++
Provides:       libavfilter-devel = %version-%release
Obsoletes:      libavfilter-devel < %version-%release
Requires:       %{name}-libavcodec-devel = %version-%release
Requires:       %{name}-libavformat-devel = %version-%release
Requires:       %{name}-libavresample-devel = %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       %{name}-libpostproc-devel = %version-%release
Requires:       %{name}-libswresample-devel = %version-%release
Requires:       %{name}-libswscale-devel = %version-%release
Requires:       libavfilter6 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavfilter-devel
The libavfilter library provides a generic audio/video filtering
framework containing several filters, sources and sinks.

This subpackage contains the headers for FFmpeg libavfilter.

%package -n libavformat57
Summary:        FFmpeg's stream format library
Group:          System/Libraries
Requires:       libavcodec57 = %version-%release
Requires:       libavutil55 = %version-%release

%description -n libavformat57
The libavformat library provides a generic framework for multiplexing
and demultiplexing (muxing and demuxing) audio, video and subtitle
streams. It encompasses multiple muxers and demuxers for multimedia
container formats.
%if !0%{?BUILD_ORIG}

This build of ffmpeg is limited in the number of codecs supported.
%endif

%package libavformat-devel
Summary:        Development files for FFmpeg's stream format library
Group:          Development/Libraries/C and C++
Provides:       libavformat-devel = %version-%release
Obsoletes:      libavformat-devel < %version-%release
Requires:       %{name}-libavcodec-devel = %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       %{name}-libswresample-devel = %version-%release
Requires:       libavformat57 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavformat-devel
The libavformat library provides a generic framework for multiplexing
and demultiplexing (muxing and demuxing) audio, video and subtitle
streams. It encompasses multiple muxers and demuxers for multimedia
container formats.

This subpackage contains the headers for FFmpeg libavformat.

%package -n libavresample3
Summary:        FFmpeg alternate audio resampling library
Group:          System/Libraries
Requires:       libavutil55 = %version-%release

%description -n libavresample3
An audio resampling library that is being provided for drop-in
compatibility with libav.

It is advised to use libswresample for new code.

%package libavresample-devel
Summary:        Development files for libavresample as present in FFmpeg
Group:          Development/Libraries/C and C++
Provides:       libavresample-devel = %version-%release
Obsoletes:      libavresample-devel < %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libavresample3 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavresample-devel
An audio resampling library that is being provided for drop-in
compatibility with libav.

It is advised to use libswresample for new code.

This subpackage contains the headers for FFmpeg's copy of libavresample.

%package -n libavutil55
Summary:        FFmpeg's utility library
Group:          System/Libraries

%description -n libavutil55
The libavutil library is a utility library to aid portable multimedia
programming. It contains safe portable string functions, random
number generators, data structures, additional mathematics functions,
cryptography and multimedia related functionality (like enumerations
for pixel and sample formats).

%package libavutil-devel
Summary:        Development files for FFmpeg's utility library
Group:          Development/Libraries/C and C++
Provides:       libavutil-devel = %version-%release
Obsoletes:      libavutil-devel < %version-%release
Requires:       libavutil55 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libavutil-devel
The libavutil library is a utility library to aid portable multimedia
programming. It contains safe portable string functions, random
number generators, data structures, additional mathematics functions,
cryptography and multimedia related functionality (like enumerations
for pixel and sample formats).

This subpackage contains the headers for FFmpeg libavutil.

%package -n libpostproc54
Summary:        FFmpeg post-processing library
Group:          System/Libraries
Requires:       libavutil55 = %version-%release

%description -n libpostproc54
A library with video postprocessing filters, such as deblocking and
deringing filters, noise reduction, automatic contrast and brightness
correction, linear/cubic interpolating deinterlacing.

%package libpostproc-devel
Summary:        Development files for the FFmpeg post-processing library
Group:          Development/Libraries/C and C++
Provides:       libpostproc-devel = %version-%release
Obsoletes:      libpostproc-devel < %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libpostproc54 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libpostproc-devel
A library with video postprocessing filters, such as deblocking and
deringing filters, noise reduction, automatic contrast and brightness
correction, linear/cubic interpolating deinterlacing.

This subpackage contains the headers for FFmpeg libpostproc.

%package -n libswresample2
Summary:        FFmpeg software resampling library
Group:          System/Libraries
Requires:       libavutil55 = %version-%release

%description -n libswresample2
The libswresample library performs audio conversion between different
sample rates, channel layout and channel formats.

%package libswresample-devel
Summary:        Development files for the FFmpeg software resampling library
Group:          Development/Libraries/C and C++
Provides:       libswresample-devel = %version-%release
Obsoletes:      libswresample-devel < %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libswresample2 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libswresample-devel
The libswresample library performs audio conversion between different
sample rates, channel layout and channel formats.

This subpackage contains the headers for FFmpeg libswresample.

%package -n libswscale4
Summary:        FFmpeg image scaling and colorspace/pixel conversion library
Group:          System/Libraries
Requires:       libavutil55 = %version-%release

%description -n libswscale4
The libswscale library performs image scaling and colorspace and
pixel format conversion operations.

%package libswscale-devel
Summary:        Development files for FFmpeg's image scaling and colorspace library
Group:          Development/Libraries/C and C++
Provides:       libswscale-devel = %version-%release
Conflicts:      libswscale-devel
Requires:       %{name}-libavutil-devel = %version-%release
Requires:       libswscale4 = %version-%release
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description libswscale-devel
The libswscale library performs image scaling and colorspace and
pixel format conversion operations.

This subpackage contains the headers for FFmpeg libswscale.

%package private-devel
Summary:        Some FFmpeg private headers
Group:          Development/Libraries/C and C++
Requires:       %{name}-libavcodec-devel = %version-%release
Requires:       %{name}-libavformat-devel = %version-%release
Requires:       %{name}-libavutil-devel = %version-%release
Provides:       ffmpeg-private-devel = %version
Obsoletes:      ffmpeg-private-devel < %version
%devel_conflicts -c < -v %{_major_version}
%devel_conflicts -c >= -v %{_major_expected}

%description private-devel
FFmpeg is a multimedia framework, able to decode, encode,
transcode, mux, demux, stream, filter and play several formats
that humans and machines have created.

This package contains some private headers for libavformat, libavcodec and
libavutil which are needed by libav-tools to build. No other package apart
from libav should depend on these private headers which are expected to
break compatibility without any notice.

%prep
%setup -qn %_name-%version
%autopatch -p1

%build
perl -i -pe 's{__TIME__|__DATE__}{"$&"}g' *.c

CFLAGS="%optflags" \
./configure \
	--prefix="%_prefix" --libdir="%_libdir" --shlibdir="%_libdir" \
	--incdir="%_includedir/ffmpeg" \
	--extra-cflags="%optflags" --optflags="%optflags" \
	--disable-htmlpages \
	--enable-pic --disable-stripping \
	--enable-shared --disable-static \
	--enable-gpl \
	--disable-openssl \
	--enable-avresample \
	--enable-libcdio \
	--enable-gnutls \
	--enable-ladspa \
%if ! %{with nvidia}
	--disable-cuda \
	--disable-cuvid \
%endif
	--enable-libass \
	--enable-libbluray \
	--enable-libcelt \
	--enable-libcdio \
	--enable-libdc1394 \
	--enable-libfreetype \
	--enable-libgsm \
	--enable-libmp3lame \
%if 0%{?suse_version} >= 1500
	--enable-libopenjpeg \
%endif
	--enable-libopus \
	--enable-libpulse \
	--enable-libspeex \
	--enable-libtheora \
	--enable-libtwolame \
%if %{with vidstab}
	--enable-libvidstab \
%endif
	--enable-libvorbis \
	--enable-libvpx \
	--enable-libwebp \
%if %{with zimg}
	--enable-libzimg \
%endif
	--enable-libzvbi \
	--enable-vaapi \
	--enable-vdpau \
%if 0%{?BUILD_ORIG}
%if %{with fdk_aac}
	--enable-libfdk_aac --enable-nonfree \
%endif
%if %{with opencore}
	--enable-libopencore-amrnb \
	--enable-libopencore-amrwb \
	--enable-version3 \
%endif
%if %{with x264}
	--enable-libx264 \
%endif
%if %{with x265}
	--enable-libx265 \
%endif
%if %{with xvid}
	--enable-libxvid \
%endif
%else
	--enable-muxers \
	--enable-demuxers \
	--disable-encoders \
	--disable-decoders \
	--disable-decoder=mpeg4,h263,h264,hevc,vc1 \
	--enable-encoder="$(perl -pe 's{^(\w*).*}{$1,}gs' <%_sourcedir/enable_encoders)" \
	--enable-decoder="$(perl -pe 's{^(\w*).*}{$1,}gs' <%_sourcedir/enable_decoders)" \

for i in MPEG4 H263 H264 HEVC VC1; do
	grep -q "#define CONFIG_${i}_DECODER 0" config.h
done
%endif

cat config.h
make %{?_smp_mflags} V=1

%global extratools aviocat cws2fws ffescape ffeval ffhash fourcc2pixfmt graph2dot ismindex pktdumper probetest qt-faststart seek_print sidxindex trasher

for i in %extratools; do
	make "tools/$i"
done

%install
b="%buildroot"
%make_install install-man

%if %{with full_build}
rm -Rf "$b/%_datadir/ffmpeg/examples"
for i in %extratools; do
	cp -a "tools/$i" "$b/%_bindir/"
done
%else
rm -Rf "$b/%_bindir" "$b/%_mandir/man1" "$b/%_datadir/ffmpeg"
%endif

# Install private headers required by libav-tools
for i in libavformat/options_table.h libavformat/os_support.h \
  libavformat/internal.h libavcodec/options_table.h libavutil/libm.h \
  libavutil/internal.h libavutil/colorspace.h libavutil/timer.h \
  libavutil/x86/emms.h libavutil/aarch64/timer.h libavutil/arm/timer.h \
  libavutil/bfin/timer.h libavutil/ppc/timer.h libavutil/x86/timer.h; do
	mkdir -p "$b/%_includedir/ffmpeg/private/"`dirname $i`
	cp -a $i "$b/%_includedir/ffmpeg/private/$i"
done

%post   -n libavcodec57 -p /sbin/ldconfig
%postun -n libavcodec57 -p /sbin/ldconfig
%post   -n libavdevice57 -p /sbin/ldconfig
%postun -n libavdevice57 -p /sbin/ldconfig
%post   -n libavfilter6 -p /sbin/ldconfig
%postun -n libavfilter6 -p /sbin/ldconfig
%post   -n libavformat57 -p /sbin/ldconfig
%postun -n libavformat57 -p /sbin/ldconfig
%post   -n libavresample3 -p /sbin/ldconfig
%postun -n libavresample3 -p /sbin/ldconfig
%post   -n libavutil55 -p /sbin/ldconfig
%postun -n libavutil55 -p /sbin/ldconfig
%post   -n libpostproc54 -p /sbin/ldconfig
%postun -n libpostproc54 -p /sbin/ldconfig
%post   -n libswresample2 -p /sbin/ldconfig
%postun -n libswresample2 -p /sbin/ldconfig
%post   -n libswscale4 -p /sbin/ldconfig
%postun -n libswscale4 -p /sbin/ldconfig

%if %{with full_build}
%files
%doc Changelog CREDITS README.md
%_bindir/*
%_mandir/man1/ff*.1*
%_datadir/ffmpeg/
%endif

%files -n libavcodec57
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavcodec.so.*

%files -n libavdevice57
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavdevice.so.*

%files -n libavfilter6
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavfilter.so.*

%files -n libavformat57
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavformat.so.*

%files -n libavresample3
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavresample.so.*

%files -n libavutil55
%license COPYING.GPLv2 LICENSE.md
%_libdir/libavutil.so.*

%files -n libpostproc54
%license COPYING.GPLv2 LICENSE.md
%_libdir/libpostproc.so.*

%files -n libswresample2
%license COPYING.GPLv2 LICENSE.md
%_libdir/libswresample.so.*

%files -n libswscale4
%license COPYING.GPLv2 LICENSE.md
%_libdir/libswscale.so.*

%files libavcodec-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavcodec/
%_libdir/libavcodec.so
%_libdir/pkgconfig/libavcodec.pc
%_mandir/man3/libavcodec.3*

%files libavdevice-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavdevice/
%_libdir/libavdevice.so
%_libdir/pkgconfig/libavdevice.pc
%_mandir/man3/libavdevice.3*

%files libavfilter-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavfilter/
%_libdir/libavfilter.so
%_libdir/pkgconfig/libavfilter.pc
%_mandir/man3/libavfilter.3*

%files libavformat-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavformat/
%_libdir/libavformat.so
%_libdir/pkgconfig/libavformat.pc
%_mandir/man3/libavformat.3*

%files libavresample-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavresample/
%_libdir/libavresample.so
%_libdir/pkgconfig/libavresample.pc

%files libavutil-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libavutil/
%_libdir/libavutil.so
%_libdir/pkgconfig/libavutil.pc
%_mandir/man3/libavutil.3*

%files libpostproc-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libpostproc/
%_libdir/libpostproc.so
%_libdir/pkgconfig/libpostproc.pc

%files libswresample-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libswresample/
%_libdir/libswresample.so
%_libdir/pkgconfig/libswresample.pc
%_mandir/man3/libswresample.3*

%files libswscale-devel
%dir %_includedir/ffmpeg/
%_includedir/ffmpeg/libswscale/
%_libdir/libswscale.so
%_libdir/pkgconfig/libswscale.pc
%_mandir/man3/libswscale.3*

%files private-devel
%_includedir/ffmpeg/private/

%changelog
* Tue Jul 31 2018 tchvatal@suse.com
- bsc#1103064 attempt to allow migration from the unprefixed devel
  packages cleanly
* Sun Jul 22 2018 tchvatal@suse.com
- Version update to 3.4.4:
  * avcodec/dvdsub_parser: Allocate input padding
  * avcodec/dvdsub_parser: Init output buf/size
  * avcodec/dirac_dwt_template: Fix signedness regression in interleave()
  * avformat/movenc: Write version 2 of audio atom if channels is not known
  * swresample/arm: rename labels to fix xcode build error
  * avcodec/imgconvert: fix possible null pointer dereference
  * avformat/movenc: Check input sample count
  * avcodec/mjpegdec: Check for odd progressive RGB
  * avformat/movenc: Check that frame_types other than EAC3_FRAME_TYPE_INDEPENDENT have a supported substream id
  * avcodec/vp8_parser: Do not leave data/size uninitialized
  * avformat/mms: Add missing chunksize check
  * avformat/pva: Check for EOF before retrying in read_part_of_packet()
  * avformat/rmdec: Do not pass mime type in rm_read_multi() to ff_rm_read_mdpr_codecdata()
  * avformat/asfdec_o: Check size_bmp more fully
  * avcodec/indeo4: Check for end of bitstream in decode_mb_info()
  * avcodec/shorten: Fix undefined addition in shorten_decode_frame()
  * avcodec/shorten: Fix undefined integer overflow
  * avcodec/jpeg2000dec: Fixes invalid shifts in jpeg2000_decode_packets_po_iteration()
  * avcodec/jpeg2000dec: Check that there are enough bytes for all tiles
  * avformat/movenc: Do not pass AVCodecParameters in avpriv_request_sample
  * avcodec/escape124: Fix spelling errors in comment
  * avcodec/ra144: Fix integer overflow in ff_eval_refl()
  * avcodec/cscd: Check output buffer size for lzo.
  * avcodec/escape124: Check buf_size against num_superblocks
  * avcodec/h264_parser: Reduce needed history for parsing mb index
  * avcodec/magicyuv: Check bits left in flags&1 branch
  * avcodec/mjpegdec: Check for end of bitstream in ljpeg_decode_rgb_scan()
  * avcodec/aacdec_fixed: Fix undefined integer overflow in apply_independent_coupling_fixed()
  * avcodec/dirac_dwt_template: Fix undefined behavior in interleave()
  * avutil/common: Fix undefined behavior in av_clip_uintp2_c()
  * fftools/ffmpeg: Fallback to duration if sample rate is unavailable
  * avformat/mov: Only set pkt->duration to non negative values
  * avcodec/h264_slice: Fix overflow in recovery_frame computation
  * avcodec/h264_ps: Move MAX_LOG2_MAX_FRAME_NUM to header so it can be used in h264_sei
  * avcodec/h264_mc_template: Only prefetch motion if the list is used.
  * avcodec/xwddec: Use ff_set_dimensions()
  * avcodec/wavpack: Fix overflow in adding tail
  * avcodec/shorten: Fix multiple integer overflows
  * avcodec/shorten: Fix undefined shift in fix_bitshift()
  * avcodec/shorten: Fix a negative left shift in shorten_decode_frame()
  * avcodec/shorten: Sanity check nmeans
  * avcodec/shorten: Check non COMM chunk len before skip in decode_aiff_header()
  * avcodec/mjpegdec: Fix integer overflow in ljpeg_decode_rgb_scan()
  * avcodec/truemotion2: Fix overflow in tm2_apply_deltas()
  * avcodec/opus_silk: Change silk_lsf2lpc() slightly toward silk/NLSF2A.c
  * avcodec/amrwbdec: Fix division by 0 in find_hb_gain()
  * avformat/mov: replace a value error by clipping into valid range in mov_read_stsc()
  * avformat/mov: Break out early if chunk_count is 0 in mov_build_index()
  * avcodec/fic: Avoid some magic numbers related to cursors
  * avcodec/g2meet: ask for sample with overflowing RGB
  * avcodec/aacdec_fixed: use 64bit to avoid overflow in rounding in apply_dependent_coupling_fixed()
  * oavcodec/aacpsdsp_template: Use unsigned for hs0X to prevent undefined behavior
  * avcodec/g723_1dec: Clip bits2 in both directions
  * avcodec/mpeg4videoenc: Use 64 bit for times in mpeg4_encode_gop_header()
  * avcodec/mlpdec: Only change noise_type if the related fields are valid
  * indeo4: Decode all or nothing of a band header.
  * avformat/mov: Only fail for STCO/STSC contradictions if both exist
  * avcodec/dirac_dwt: Fix integer overflow in COMPOSE_DD97iH0 / COMPOSE_DD137iL0
  * avcodec/fic: Check available input space for cursor
  * avcodec/g2meet: Check RGB upper limit
  * avcodec/jpeg2000dec: Fix undefined shift in the jpeg2000_decode_packets_po_iteration() CPRL case
  * avcodec/jpeg2000dec: Skip init for component in CPRL if nothing is to be done
  * avcodec/g2meet: Change order of operations to avoid undefined behavior
  * avcodec/flac_parser: Fix infinite loop
  * avcodec/wavpack: Fix integer overflow in DEC_MED() / INC_MED()
  * avcodec/wavpack: Fix integer overflow in wv_unpack_stereo()
  * avcodec/error_resilience: Fix integer overflow in filter181()
  * avcodec/h263dec: Check slice_ret in mspeg4 slice loop
  * avcodec/elsdec: Fix memleaks
  * avcodec/vc1_block: simplify ac_val computation
  * avcodec/ffv1enc: Check that the crc + version combination is supported
  * lavf/http.c: Free allocated client URLContext in case of error.
  * avcodec/dsicinvideo: Fail if there is only a small fraction of the data available that comprises a full frame
  * avcodec/dsicinvideo: Propagate errors from cin_decode_rle()
  * avcodec/dfa: Check dimension against maximum
  * avcodec/cinepak: Skip empty frames
  * avcodec/cinepak: move some checks prior to frame allocation
  * swresample/arm: remove unintentional relocation.
  * doc/APIchanges: Fix typos in hashes
  * avformat/utils: Check cur_dts in update_initial_timestamps() more
  * avcodec/utils: Enforce minimum width also for VP5/6
  * avcodec/truemotion2: Propagate out of bounds error from GET_TOK()
  * avformat/utils: Fix integer overflow in end time calculation in update_stream_timings()
  * avcodec/mjpegdec: Check input buffer size.
  * avcodec/h264_slice: Fix integer overflow with last_poc
  * avformat/mov: Fix extradata memleak
  * lavc/libopusdec: Allow avcodec_open2 to call .close
  * avcodec/movtextdec: Check style_start/end
  * avcodec/aacsbr_fixed: Fix integer overflow in sbr_hf_assemble()
  * libavcodec/rv34: error out earlier on missing references
  * swresample/swresample: Fix for seg fault in swr_convert_internal() -> sum2_float during dithering.
  * avcodec/aacdec_fixed: Fix integer overflow in apply_independent_coupling_fixed()
  * avcodec/cscd: Error out when LZ* decompression fails
  * avcodec/imgconvert: Fix loss mask bug in avcodec_find_best_pix_fmt_of_list()
  * avfilter/vf_signature: use av_strlcpy()
  * avcodec/utvideodec: Set pro flag based on fourcc
  * avcodec/wmalosslessdec: Fix null pointer dereference in decode_frame()
  * avcodec/tableprint_vlc: Fix build failure with --enable-hardcoded-tables
  * avformat/mov: Move +1 in check to avoid hypothetical overflow in add_ctts_entry()
  * avcodec/get_bits: Make sure the input bitstream with padding can be addressed
  * avformat/mov: Check STSC and remove invalid entries
  * avcodec/nuv: rtjpeg with dimensions less than 16 would result in no decoded pixels thus reject it
  * avcodec/nuv: Check for minimum input size for uncomprssed and rtjpeg
  * avcodec/wmalosslessdec: Reset num_saved_bits on error path
  * avformat/mov: Fix integer overflows related to sample_duration
  * avformat/img2dec: fix infinite loop
  * avformat/oggparsedaala: Do not adjust AV_NOPTS_VALUE
  * avformat/oggparseogm: Check lb against psize
  * avformat/oggparseogm: Fix undefined shift in ogm_packet()
  * avformat/avidec: Fix integer overflow in cum_len check
  * avformat/oggparsetheora: Do not adjust AV_NOPTS_VALUE
  * avformat/utils: Fix integer overflow of fps_first/last_dts
  * avformat/oggdec: Fix metadata memleak on multiple headers
  * libavformat/oggparsevorbis: Fix memleak on multiple headers
  * avformat/mov: Fix integer overflow in mov_get_stsc_samples()
  * avcodec/truemotion2rt: Check input buffer size
  * avcodec/g2meet: Check tile dimensions with av_image_check_size2()
  * avcodec/exr: fix invalid shift in unpack_14()
  * avcodec/bintext: sanity check dimensions
  * avcodec/utvideodec: Check subsample factors
  * avcodec/smc: Check input packet size
  * avcodec/cavsdec: Check alpha/beta offset
  * avcodec/diracdec: Fix integer overflow in mv computation
  * avcodec/h264_parse: Clear invalid chroma weights in ff_h264_pred_weight_table()
  * avcodec/aacdec_templat: Fix integer overflow in apply_ltp()
  * avcodec/jpeg2000dwt: Fix integer overflows in sr_1d53()
  * avcodec/diracdec: Use int64 in global mv to prevent overflow
  * avcodec/dxtory: Remove code that corrupts dimensions
  * avcodec/dirac_dwt_template: Fix Integer overflow in horizontal_compose_dd137i()
  * avcodec/hevcdec: Check luma/chroma_log2_weight_denom
  * avcodec/jpeg2000dec: Use av_image_check_size2()
  * avcodec/vp8: Check for bitstream end before vp7_fade_frame()
  * avcodec/exr: Check remaining bits in last get code loop
  * avutil/common: Fix integer overflow in av_clip_uint8_c() and av_clip_uint16_c()
  * avcodec/h264_cabac: Tighten allowed coeff_abs range
  * avcodec/h264_cavlc: Set valid qscale value in ff_h264_decode_mb_cavlc()
  * avdevice/iec61883: free the private context at the end
  * avdevice/iec61883: return reference counted packets
  * configure: add nvcc to CMDLINE_SET
  * avcodec/mpeg4_unpack_bframes: make sure the packet is writable when data needs to be changed
  * avcodec/mp3_header_decompress: don't free the user provided packet on error
  * avcodec/extract_extradata: zero initalize the padding bytes in all allocated buffers
  * avformat/hvcc: zero initialize the nal buffers past the last written byte
  * swresample/rematrix: fix update of channel matrix if input or output layout is undefined
  * avformat/matroskadec: ignore CodecPrivate if the stream is VP9
- drop patch merged upstream:
  * 0001-avformat-img2dec-fix-infinite-loop.patch
* Fri Jul  6 2018 tchvatal@suse.com
- Fix typo in swresample name
* Wed Jul  4 2018 tchvatal@suse.com
- Conditionalize vidstab so it gets working on Leap
- full_build only on Leap 42 and 15, not on TW
* Tue Jul  3 2018 tchvatal@suse.com
- Add macros to allow conflicting with all other devel projects
  to ensure we always install only one specific ffmpeg
* Sat Jun 30 2018 tchvatal@suse.com
- Enable vidstab on tumbleweed
* Sat Jun 23 2018 bjorn.lie@gmail.com
- Conditionalize pkgconfig(libopenjpeg) and pkgconfig(sdl2)
  BuildRequires: Fix build for SLE 12 SP3.
- Enable pkgconfig(vidstab) BuildRequires unconditionally, now
  available in openSUSE.
* Thu Jun 14 2018 tchvatal@suse.com
- Conditionalize zimg for Leap 42.3
* Thu Jun 14 2018 tchvatal@suse.com
- Split out the develpkgs again
- Use %%autopatch
* Wed Jun 13 2018 tchvatal@suse.com
- Sync with ffmpeg-4
* Thu Apr 26 2018 jengelh@inai.de
- Add 0001-avformat-img2dec-fix-infinite-loop.patch [boo#1090826]
* Mon Apr  9 2018 enzokiel@kabelmail.de
- Enable build against libzimg.
* Tue Mar 27 2018 jengelh@inai.de
- Add 0001-opusenc-psy-disable-stereo-searches.patch
  to fix a crash in the Opus encoder when outputting mono.
- Enable FFmpeg Opus encoder as a selectable runtime alternative
  to Xiph libopus.
* Fri Mar 23 2018 alarrosa@suse.com
- Create a new package ffmpeg-private-devel which contains some
  headers under /usr/include/ffmpeg/private that were not installed
  by upstream. Those headers are needed by the libav package in order
  to build avconv and other tools using the libav* libraries generated
  by ffmpeg instead of its own. No other package should require
  ffmpeg-private-devel.
* Wed Mar 21 2018 alarrosa@suse.com
- Build and install also the sidxindex tool
* Tue Feb 20 2018 bjorn.lie@gmail.com
- Enable mpeg1video and mpeg2video in enable_decoders, and remove
  it from disable-decoders call given to configure, mpeg2 now
  available in openSUSE.
* Tue Feb 13 2018 nico.kruber@gmail.com
- enable video stabilization/deshaking via libvidstab (optional)
* Mon Feb 12 2018 jengelh@inai.de
- Update to new bugfix release 3.4.2
  * Fix integer overflows, multiplication overflows, undefined
    shifts, and verify buffer lengths.
  * avfilter/vf_transpose: Fix used plane count
    [boo#1078488, CVE-2018-6392]
  * avcodec/utvideodec: Fix bytes left check in decode_frame()
    [boo#1079368, CVE-2018-6621]
- Enable use of libzvbi for displaying teletext subtitles.
- Fixed a DoS in swri_audio_convert(), added cve-2017-17555.diff
  [boo#1072366, CVE-2017-17555].
* Mon Dec 11 2017 jengelh@inai.de
- Update to new bugfix release 3.4.1
  * Fixed integer overflows, division by zero, illegal bit shifts
  * Fixed the gmc_mmx function which failed to validate width
    and height [boo#1070762, CVE-2017-17081]
  * Fixed out-of-bounds in VC-2 encoder [boo#1069407, CVE-2017-16840]
  * ffplay: use SDL2 audio API
- Removed 0001-avcodec-x86-mpegvideodsp-Fix-signedness-bug-in-need_.patch
  (upstreamed).
* Fri Dec  1 2017 jengelh@inai.de
- Add 0001-avcodec-x86-mpegvideodsp-Fix-signedness-bug-in-need_.patch
  [boo#1070762]
* Thu Nov 30 2017 jslaby@suse.com
- install also doc/ffserver.conf
* Tue Oct 31 2017 jengelh@inai.de
- Get rid of ffmpeg-pkgconfig-version.patch.
* Mon Oct 16 2017 jengelh@inai.de
- Update to new upstream release 3.4
  * New video filters: deflicker, doublewave, lumakey, pixscope,
    oscilloscope, robterts, limiter, libvmaf, unpremultiply,
    tlut2, floodifll, pseudocolor, despill, convolve, vmafmotion.
  * New audio filters: afir, crossfeed, surround, headphone,
    superequalizer, haas.
  * Some video filters with several inputs now use a common set
    of options: blend, libvmaf, lut3d, overlay, psnr, ssim. They
    must always be used by name.
  * librsvg support for svg rasterization
  * spec-compliant VP9 muxing support in MP4
  * Remove the libnut and libschroedinger muxer/demuxer wrappers
  * drop deprecated qtkit input device (use avfoundation instead)
  * SUP/PGS subtitle muxer
  * VP9 tile threading support
  * KMS screen grabber
  * CUDA thumbnail filter
  * V4L2 mem2mem HW assisted codecs
  * Rockchip MPP hardware decoding
  * (Not in openSUSE builds, only original ones:)
  * Gremlin Digital Video demuxer and decoder
  * Additional frame format support for Interplay MVE movies
  * Dolby E decoder and SMPTE 337M demuxer
  * raw G.726 muxer and demuxer, left- and right-justified
  * NewTek NDI input/output device
  * FITS demuxer, muxer, decoder and encoder
- Fixed a double free in huffyuv [boo#1064577, CVE-2017-15186]
- Fixed an out-of-bounds in ffv1dec [boo#1066428, CVE-2017-15672]
- Fixed a denial of service in rtmppkt [boo#1082335, CVE-2017-11665]
* Tue Sep 12 2017 jengelh@inai.de
- Update to new upstream release 3.3.4.
  * avutil/pixdesc: fixed NULL deref in av_color_primaries_name
    [CVE-2017-14225] [boo#1058018]
  * avformat/asfdec: Fix DoS in asf_build_simple_index
    [CVE-2017-14223] [boo#1058019]
  * avformat/mov: Fix DoS in read_tfra
    [CVE-2017-14222] [boo#1058020].
- Dropped integrated patches:
  D 0001-avformat-hls-Fix-DoS-due-to-infinite-loop.patch
  D 0001-avformat-nsvdec-Fix-DoS-due-to-lack-of-eof-check-in-.patch
  D 0002-avformat-asfdec-Fix-DoS-due-to-lack-of-eof-check.patch
  D 0002-avformat-mxfdec-Fix-DoS-issues-in-mxf_read_index_ent.patch
  D 0003-avformat-cinedec-Fix-DoS-due-to-lack-of-eof-check.patch
  D 0003-avformat-mxfdec-Fix-Sign-error-in-mxf_read_primer_pa.patch
  D 0004-avformat-rmdec-Fix-DoS-due-to-lack-of-eof-check.patch
  D 0005-avformat-rl2-Fix-DoS-due-to-lack-of-eof-check.patch
  D 0006-avformat-mvdec-Fix-DoS-due-to-lack-of-eof-check.patch
* Thu Sep  7 2017 jengelh@inai.de
- Add 0001-avformat-nsvdec-Fix-DoS-due-to-lack-of-eof-check-in-.patch
  [CVE-2017-14171] [boo#1057539],
  0002-avformat-mxfdec-Fix-DoS-issues-in-mxf_read_index_ent.patch
  [CVE-2017-14170] [boo#1057537],
  0003-avformat-mxfdec-Fix-Sign-error-in-mxf_read_primer_pa.patch
  [CVE-2017-14169] [boo#1057536]
* Mon Sep  4 2017 jengelh@inai.de
- Add 0001-avformat-hls-Fix-DoS-due-to-infinite-loop.patch
  [CVE-2017-14058] [boo#1056762],
  0002-avformat-asfdec-Fix-DoS-due-to-lack-of-eof-check.patch
  [CVE-2017-14057] [boo#1056761],
  0003-avformat-cinedec-Fix-DoS-due-to-lack-of-eof-check.patch
  [CVE-2017-14059] [boo#1056763],
  0004-avformat-rmdec-Fix-DoS-due-to-lack-of-eof-check.patch
  [CVE-2017-14054] [boo#1056765],
  0005-avformat-rl2-Fix-DoS-due-to-lack-of-eof-check.patch
  (code not enabled in openSUSE, though in packman)
  [CVE-2017-14056] [boo#1056760],
  0006-avformat-mvdec-Fix-DoS-due-to-lack-of-eof-check.patch
  [CVE-2017-14055] [boo#1056766]
* Sat Aug 26 2017 jengelh@inai.de
- Unconditionalize celt, ass, openjpeg, webp, netcdf, libva, vdpau.
* Fri Aug 25 2017 olaf@aepfle.de
- Build unconditionally with lame and twolame
* Sun Jul 30 2017 jengelh@inai.de
- Update to maintenance release 3.3.3
  * Various fixes for integer overflows, too-large bit shifts
    and buffer length checks.
- Drop 0001-avcodec-apedec-Fix-integer-overflow.patch
  (included upstream)
* Tue Jul 18 2017 jengelh@inai.de
- Add 0001-avcodec-apedec-Fix-integer-overflow.patch
  to address CVE-2017-11399 [boo#1049095]
* Fri Jun 23 2017 davejplater@gmail.com
- Enabled cuda and cuvid for unrestricted build.
- Fixed typos in devel package descriptions.
* Wed Jun  7 2017 jengelh@inai.de
- Update to new upstream release 3.3.2
  * Various fixes for integer overflows and too-large bit shifts
* Wed May 31 2017 davejplater@gmail.com
- Disable cuda support to fix boo#1041794:
  ffmpeg 3.3. enablement of cuda prevents H264/avc1.4d400d videos
  from playing on Youtube
- Refreshed patches: ffmpeg-codec-choice.diff
  ffmpeg-libcdio_cdda-pkgconfig.patch
  ffmpeg-pkgconfig-version.patch and ffmpeg-new-coder-errors.diff
* Wed May 31 2017 jengelh@inai.de
- Add additional checks to ensure MPEG is off
* Fri May 19 2017 jengelh@inai.de
- Update to new upstream release 3.3.1
  * Fix uninitialized variables, signed integer overflow,
    excess shift operations. Add boundary checks.
* Tue Apr 18 2017 jengelh@inai.de
- Enable ac3 per request from idonmez
* Fri Apr 14 2017 jengelh@inai.de
- Update to new upstream release 3.3
  * EBU R128 implementation now within ffmpeg, not relying on
    external library anymore
  * New video filters "premultiply", "readeia608", "threshold",
    "midequalizer"
  * Support for spherical videos
  * New decoders: 16.8 and 24.0 floating point PCM, XPM
  * New demuxers: MIDI Sample Dump Standard, Sample Dump eXchange demuxer
  * MJPEG encoding uses Optimal Huffman tables now
  * Native Opus encoder
  * Support .mov with multiple sample description tables
  * Removed the legacy X11 screen grabber, use XCB instead
  * Removed asyncts filter (use af_aresample instead)
  * resolved CVE-2016-10190 [boo#1022920],
    CVE-2016-10191 [boo#1022921], CVE-2016-10192 [boo#1022922],
    CVE-2017-7859 [boo#1034183], CVE-2017-7862 [boo#1034181],
    CVE-2017-7863 [boo#1034179], CVE-2017-7865 [boo#1034177],
    CVE-2017-7866 [boo#1034176]
* Thu Apr 13 2017 idonmez@suse.com
- Enable mp3 decoding
* Sat Feb 18 2017 dimstar@opensuse.org
- Have libavcodec57 additionally provide libavcodec57(unrestricted)
  when building unrestricted: allow third party packages to require
  the unrestricted codec. The existing -full provides is not
  suitable as it can be provided by multiple libavcodec* packages,
  whereas we require a specific ABI version.
* Sat Feb 11 2017 jengelh@inai.de
- Update to new upstream release 3.2.4
  * lavf/mov.c: Avoid heap allocation wrap in mov_read_hdlr
  * lavf/mov.c: Avoid OOB in mov_read_udta_string()
  * lavf/mov.c: Avoid heap allocation wraps in mov_read_{senc,saiz}()
* Sat Feb 11 2017 olaf@aepfle.de
- Make sure each subpkg comes from the same src.rpm
* Tue Feb  7 2017 jengelh@inai.de
- Update to new upstream release 3.2.3
  * Maintenance release with bugfixes
  * ffplay: fix sws_scale possible out of bounds array access
- Drop version number from patch: ffmpeg-2.4.5-arm6l.patch ->
  ffmpeg-arm6l.diff
* Tue Jan  3 2017 olaf@aepfle.de
- Wrap netcdf support in build condtional because it is a drop-in pkg
* Tue Dec 20 2016 tchvatal@suse.com
- Enable all muxers and demuxers as they are just descriptor of format
  thus do not change the behaviour in any relevant way.
  * The best user now gets is proper interpretation of the format and
    failure to play it without proper de/encoder
  * Recommended by vlc team to be done this way :)
* Tue Dec  6 2016 jengelh@inai.de
- Update to new upstream release 3.2.2
  * avformat/rtmppkt: Check for packet size mismatches
  * avcodec/flacdec: Fix undefined shift in decode_subframe()
  * avcodec/flacdec: Fix signed integer overflow in
    decode_subframe_fixed()
  * avcodec/flacdsp_template: Fix undefined shift in
    flac_decorrelate_indep_c
* Sat Nov 26 2016 aloisio@gmx.com
- Update to version 3.2.1:
  * avcodec/aac_adtstoasc_bsf: validate and forward extradata
    if the stream is already ASC
  * libopusdec: default to stereo for invalid number of
    channels
  * sbgdec: prevent NULL pointer access
  * rmdec: validate block alignment
  * smacker: limit recursion depth of smacker_decode_bigtree
  * mxfdec: fix NULL pointer dereference in mxf_read_packet_old
  * ffmdec: validate codec parameters
  * avformat/mpeg: Adjust vid probe threshold to correct
    mis-detection
  * avcodec/avpacket: fix leak on realloc in
    av_packet_add_side_data()
  * avformat/apngenc: use the stream parameters extradata if
    available
  * ffprobe: fix crash in case -of is specified with an empty
    string
  * exr: fix out-of-bounds read
  * libschroedingerdec: fix leaking of framewithpts
  * filmstripdec: correctly check image dimensions
  * icodec: fix leaking pkt on error
  * dvbsubdec: fix division by zero in compute_default_clut
  * escape124: reject codebook size 0
  * mpegts: prevent division by zero
  * matroskadec: fix NULL pointer dereference in
    webm_dash_manifest_read_header
  * mxfdec: fix NULL pointer dereference
  * avcodec/mpeg4videodec: Workaround interlaced mpeg4 edge MC
    bug
  * avcodec/mpegvideo: Fix edge emu buffer overlap with
    interlaced mpeg4
  * avcodec/ituh263dec: Avoid spending a long time in slice
    sync
  * avcodec:  Check side data size before use
  * avformat/flvdec: Fix regression losing streams
* Fri Oct 28 2016 jengelh@inai.de
- Update to new upstream release 3.2
  * SDL2 output device and ffplay support
  * SDL1 output device and SDL1 support removed
  * New: libopenmpt demuxer, fifo muxer, True Audio (TTA) muxer
  * New filters: weave, gblur, avgblur, sobel, prewitt,
  vaguedenoiser, yuvtestsrc, lut2, hysteresis, maskedclamp,
  crystalizer, acrusher, bitplanenoise, sidedata, asidedata
  * Non-Local Means (nlmeans) denoising filter
  * 16-bit support in curves filter and selectivecolor filter
  * Added threads option per filter instance
  * The "curves" filter does not automatically insert points at x=0
  and x=1 anymore
  * Matroska muxer now writes CRC32 elements by default in all
  Level 1 elements
  * New "tee" protocol
  * VP8 in Ogg muxing
  * Floating point support in ALS decoder
  * Extended mov edit list support
  * Changed mapping of RTP MIME type G726 to codec g726le.
- Drop ffmpeg-fix-CONFIG_VC1DSP-changes.patch
  (no longer needed)
* Fri Oct 28 2016 olaf@aepfle.de
- Enable libfdk_aac if it is available at buildtime
* Sat Oct 22 2016 aloisio@gmx.com
- Update to version 3.1.5
  * avformat/mxfdec: Check size to avoid integer overflow in
    mxf_read_utf16_string()
  * avcodec/mpegvideo_enc: Clear mmx state in
    ff_mpv_reallocate_putbitbuffer()
  * avcodec/utils: Clear MMX state before returning from
    avcodec_default_execute*()
  * libopenjpegenc: fix out-of-bounds reads when filling the
    edges
  * libopenjpegenc: stop reusing image data buffer for
    openjpeg 2
  * avformat/utils: Update codec_id before using it in the
    parser init
  * ffmpeg: remove unused and errorneous AVFrame timestamp
    check
  * Support for MIPS cpu P6600
  * avutil/mips/generic_macros_msa: rename macro variable
    which causes segfault for mips r6
* Sat Oct  1 2016 aloisio@gmx.com
- Update to version 3.1.4
  * avformat/avidec: Check nb_streams in read_gab2_sub()
  * avformat/avidec: Remove ancient assert
  * avfilter/vf_colorspace: fix range for output colorspace
    option
  * lavc/mediacodecdec_h264: fix SODB escaping
  * avcodec/nvenc: fix const options for hevc gpu setting
  * avformat/avidec: Fix memleak with dv in avi
  * lavc/movtextdec.c: Avoid infinite loop on invalid data.
  * avcodec/ansi: Check dimensions
  * avcodec/cavsdsp: use av_clip_uint8() for idct
  * avformat/movenc: Check packet in mov_write_single_packet()
    too
  * avformat/movenc: Factor check_pkt() out
  * avformat/utils: fix timebase error in avformat_seek_file()
  * avcodec/g726: Add missing ADDB output mask
  * avcodec/avpacket: clear side_data_elems
  * avformat/movenc: Check first DTS similar to dts difference
  * avcodec/ccaption_dec: Use simple array instead of AVBuffer
  * avcodec/svq3: Reintroduce slice_type
  * avformat/mov: Fix potential integer overflow in
    mov_read_keys
  * swscale/swscale_unscaled: Try to fix
    Rgb16ToPlanarRgb16Wrapper() with slices
  * swscale/swscale_unscaled: Fix packed_16bpc_bswap() with
    slices
  * avformat/avidec: Fix infinite loop in avi_read_nikon()
  * lavf/utils: Avoid an overflow for huge negative durations.
  * avformat/hls: Fix handling of EXT-X-BYTERANGE streams over
    2GB
  * lavc/avpacket: Fix undefined behaviour, do not pass a null
    pointer to memcpy().
  * lavc/mjpegdec: Do not skip reading quantization tables.
  * cmdutils: fix implicit declaration of SetDllDirectory
    function
* Mon Aug 29 2016 stefan.bruens@rwth-aachen.de
- Fix linking errors for arm and aarch64 builds, boo#995937
  * Add ffmpeg-fix-CONFIG_VC1DSP-changes.patch
* Sat Aug 27 2016 aloisio@gmx.com
- Update to version 3.1.3
  * examples/demuxing_decoding: convert to codecpar
  * avcodec/exr: Check tile positions
  * avcodec/aacenc: Tighter input checks
  * avformat/wtvdec: Check pointer before use
  * libavcodec/wmalosslessdec: Check the remaining bits
  * avcodec/adpcm: Fix adpcm_ima_wav padding
  * avcodec/svq3: fix slice size check
  * avcodec/diracdec: Check numx/y
  * avcodec/h2645_parse: fix nal size
  * avcodec/h2645_parse: Use get_nalsize() in
    ff_h2645_packet_split()
  * h2645_parse: only read avc length code at the correct
    position
  * h2645_parse: don't overread AnnexB NALs within an avc
    stream
  * avcodec/h264_parser: Factor get_avc_nalsize() out
  * avcodec/cfhd: Increase minimum band dimension to 3
  * avcodec/indeo2: check ctab
  * avformat/swfdec: Fix inflate() error code check
  * avcodec/rawdec: Fix bits_per_coded_sample checks
  * vcodec/h2645_parse: Clear buffer padding
  * avcodec/h2645: Fix NAL unit padding
  * avfilter/drawutils: Fix single plane with alpha
  * cmdutils: check for SetDllDirectory() availability
* Tue Aug  9 2016 aloisio@gmx.com
- Update to version 3.1.2:
  * avcodec/rawdec: Fix palette handling with changing
    palettes
  * avcodec/raw: Fix decoding of ilacetest.mov
  * avformat/mov: Enable mp3 parsing if a packet needs it
  * avformat/hls: Sync starting segment across variants on
    live streams
  * avformat/hls: Fix regression with ranged media segments
  * avcodec/ffv1enc: Fix assertion failure with non zero
    bits per sample
  * avfilter/af_hdcd: small fix in af_hdcd.c where gain was
    not being adjusted for "attenuate slowly"
  * avformat/oggdec: Fix integer overflow with invalid pts
  * libavcodec/dnxhd: Enable 12-bit DNxHR support.
  * lavc/vaapi_encode_h26x: Fix a crash if "." is not the
    decimal separator.
  * avcodec/vp9_parser: Check the input frame sizes for
    being consistent
  * avformat/flvdec: parse keyframe before a/v stream was
    created add_keyframes_index() when stream created or
    keyframe parsed
  * libavformat/rtpdec_asf: zero initialize the AVIOContext
    struct
  * libx264: Increase x264 opts character limit to 4096
  * avcodec/h264_parser: Set sps/pps_ref
  * librtmp: Avoid an infinite loop setting connection
    arguments
  * avformat/oggparsevp8: fix pts calculation on pages
    ending with an invisible frame
  * lavf/vplayerdec: Improve auto-detection.
  * lavc/mediacodecdec_h264: properly convert extradata to
    annex-b
* Fri Jul 29 2016 jengelh@inai.de
- Build with netcdf so as to enable af_sofalizer [boo#983398]
* Fri Jul  1 2016 aloisio@gmx.com
- Update to version 3.1.1
  * doc/APIchanges: document the lavu/lavf field moves
  * avformat/avformat: Move new field to the end of AVStream
  * avformat/utils: update deprecated AVStream->codec when the context is updated
  * avutil/frame: Move new field to the end of AVFrame
  * libavcodec/exr : fix decoding piz float file.
  * avformat/mov: Check sample size
  * lavfi: Move new field to the end of AVFilterContext
  * lavfi: Move new field to the end of AVFilterLink
  * ffplay: Fix usage of private lavfi API
  * lavc/mediacodecdec_h264: add missing NAL headers to SPS/PPS buffers
  * lavc/pnm_parser: disable parsing for text based PNMs
* Mon Jun 27 2016 aloisio@gmx.com
- Update to version 3.1
  * DXVA2-accelerated HEVC Main10 decoding
  * fieldhint filter
  * loop video filter and aloop audio filter
  * Bob Weaver deinterlacing filter
  * firequalizer filter
  * datascope filter
  * bench and abench filters
  * ciescope filter
  * protocol blacklisting API
  * MediaCodec H264 decoding
  * VC-2 HQ RTP payload format (draft v1) depacketizer and
    packetizer
  * VP9 RTP payload format (draft v2) packetizer
  * AudioToolbox audio decoders
  * AudioToolbox audio encoders
  * coreimage filter (GPU based image filtering on OSX)
  * libdcadec removed
  * bitstream filter for extracting DTS core
  * ADPCM IMA DAT4 decoder
  * musx demuxer
  * aix demuxer
  * remap filter
  * hash and framehash muxers
  * colorspace filter
  * hdcd filter
  * readvitc filter
  * VAAPI-accelerated format conversion and scaling
  * libnpp/CUDA-accelerated format conversion and scaling
  * Duck TrueMotion 2.0 Real Time decoder
  * Wideband Single-bit Data (WSD) demuxer
  * VAAPI-accelerated H.264/HEVC/MJPEG encoding
  * DTS Express (LBR) decoder
  * Generic OpenMAX IL encoder with support for Raspberry Pi
  * IFF ANIM demuxer & decoder
  * Direct Stream Transfer (DST) decoder
  * loudnorm filter
  * MTAF demuxer and decoder
  * MagicYUV decoder
  * OpenExr improvements (tile data and B44/B44A support)
  * BitJazz SheerVideo decoder
  * CUDA CUVID H264/HEVC decoder
  * 10-bit depth support in native utvideo decoder
  * libutvideo wrapper removed
  * YUY2 Lossless Codec decoder
- Added minimum requirement for libva (0.35.0, matched by
  1.3.0 package)
* Tue May 31 2016 robert.munteanu@gmail.com
- Guard usage of opencore using bcond_with, boo#980542
* Thu Apr 28 2016 aloisio@gmx.com
- Update to version 3.0.2
  * avcodec/ttaenc: Reallocate packet if its too small
  * configure: build fix for P5600 with mips code restructuring
  * mips: add support for R6
  * pgssubdec: fix subpicture output colorspace and range
  * avcodec/ac3dec: Reset SPX when switching from EAC3 to AC3
  * avfilter/vf_drawtext: Check return code of load_glyph()
  * avformat/mux: Check that deinit is set before calling it
  * avcodec/takdec: add code that got somehow lost in process of
    REing
  * avcodec/apedec: fix decoding of stereo files with one
    channel full of silence
  * avcodec/avpacket: Fix off by 5 error
  * avcodec/h264: Fix for H.264 configuration parsing
  * avcodec/bmp_parser: Ensure remaining_size is not too small
    in startcode packet crossing corner case
  * avcodec/pngdec: Fix alpha detection with skip_frame
  * Changelog: Make formating consistent
  * avfilter/src_movie: fix how we check for overflows with
    seek_point
  * avcodec/j2kenc: Add attribution to OpenJPEG project:
- Dropped dcadec (libdca was merged upstream)
* Mon Apr 25 2016 jengelh@inai.de
- Add ffmpeg-codec-choice.diff
* Sun Apr 17 2016 olaf@aepfle.de
- Remove ffmpeg-devel subpackage.
  All users have been converted to pkgconfig
  Add Provides/Obsoletes to libavdevice-devel
* Sun Apr 10 2016 jengelh@inai.de
- Add ffmpeg-new-coder-errors.diff
* Wed Apr  6 2016 jengelh@inai.de
- Another try at organizing the codec-enable list.
  Enable video: AYUV, Dirac, MJPEG, rawvideo, Theora, VP8, VP9, WebP,
  zlib
  Enable audio: Celt, GSM, Opus, Speex, Vorbis
  Enable subtitle: ASS/SSA text, SRT text, UTF-8 plaintext
* Wed Mar 30 2016 jengelh@inai.de
- Update to new maintenance release 3.0.1
  * vc2enc: fix use of uninitialized variables in the rate control
  system
  * postproc: fix an unaligned access
  * lavc/hevc: Allow arbitrary garbage in bytestream as long as at
  least one NAL unit is found.
* Tue Feb 16 2016 olaf@aepfle.de
- Update included pkgconfig files to require the exact version
  of ffmpeg pc files, instead of any later version
  ffmpeg-pkgconfig-version.patch
* Mon Feb 15 2016 idonmez@suse.com
- Remove the optional vo-aacenc dependency, upstream removed it.
* Mon Feb 15 2016 jengelh@inai.de
- Update to new upstream release 3.0
  * New filters: extrastereo, ocr, alimiter, stereowiden, stereotools,
  rubberband, tremolo, agate, chromakey, displace, and many more.
  * ffplay dynamic volume control
  * audio high-order multiband parametric equalizer
  * automatic bitstream filtering
* Tue Feb  2 2016 aloisio@gmx.com
- Update to version 2.8.6
  * avcodec/jpeg2000dec: More completely check cdef
  * avutil/opt: check for and handle errors in av_opt_set_dict2()
  * avcodec/flacenc: fix calculation of bits required in case
    of custom sample rate
  * avformat: Document urls a bit
  * avformat/libquvi: Set default demuxer and protocol
    limitations
  * avformat/concat: Check protocol prefix
  * doc/demuxers: Document enable_drefs and use_absolute_path
  * avcodec/mjpegdec: Check for end for both bytes in unescaping
  * avcodec/mpegvideo_enc: Check for integer overflow in
    ff_mpv_reallocate_putbitbuffer()
  * avformat/avformat: Replace some references to filenames by
    urls
  * avcodec/wmaenc: Check ff_wma_init() for failure
  * avcodec/mpeg12enc: Move high resolution thread check to
    before initializing threads
  * avformat/img2dec: Use AVOpenCallback
  * avformat/avio: Limit url option parsing to the documented
    cases
  * avformat/img2dec: do not interpret the filename by default
    if a IO context has been opened
  * avcodec/ass_split: Fix null pointer dereference in
    ff_ass_style_get()
  * mov: Add an option to toggle dref opening
  * avcodec/gif: Fix lzw buffer size
  * avcodec/put_bits: Assert buf_ptr in flush_put_bits()
  * avcodec/tiff: Check subsample & rps values more completely
  * swscale/swscale: Add some sanity checks for srcSlice*
    parameters
  * swscale/x86/rgb2rgb_template: Fix planar2x() for short
    width
  * swscale/swscale_unscaled: Fix odd height inputs for
    bayer_to_yv12_wrapper()
  * swscale/swscale_unscaled: Fix odd height inputs for
    bayer_to_rgb24_wrapper()
  * avcodec/aacenc: Check both channels for finiteness
  * asfdec_o: check for too small size in asf_read_unknown
  * asfdec_o: break if EOF is reached after
    asf_read_packet_header
  * asfdec_o: make sure packet_size is non-zero before seeking
  * asfdec_o: prevent overflow causing seekback
  * asfdec_o: check avio_skip in asf_read_simple_index
  * asfdec_o: reject size > INT64_MAX in asf_read_unknown
  * asfdec_o: only set asf_pkt->data_size after sanity checks
  * Merge commit '8375dc1dd101d51baa430f34c0bcadfa37873896'
  * dca: fix misaligned access in avpriv_dca_convert_bitstream
  * brstm: fix missing closing brace
  * brstm: also allocate b->table in read_packet
  * brstm: make sure an ADPC chunk was read for adpcm_thp
  * vorbisdec: reject rangebits 0 with non-0 partitions
  * vorbisdec: reject channel mapping with less than two
    channels
  * ffmdec: reset packet_end in case of failure
  * avformat/ipmovie: put video decoding_map_size into packet
    and use it in decoder
  * avformat/brstm: fix overflow
* Sun Jan 17 2016 idonmez@suse.com
- Update to version 2.8.5
  * Fixes CVE-2016-1897 and CVE-2016-1898 [boo#961937]
* Mon Dec 28 2015 idonmez@suse.com
- Update to version 2.8.4
  * Many bugfixes, see the included Changelog for all the changes.
  * resolving CVE-2015-8661 [boo#960385], CVE-2015-8662 [boo#960384],
  CVE-2015-8663 [boo#960383]
- Drop ffmpeg-remove_some_unused_ctrl_id_mappings.patch, fixed
  upstream.
* Tue Dec 22 2015 olaf@aepfle.de
- Obsolete ffmpeg-tools from packman
* Mon Dec 21 2015 jengelh@inai.de
- Add some provides to make it easier for firefox to recommend
  this package for installation
* Sat Dec 19 2015 joerg.lorenzen@ki.tng.de
- Added patch ffmpeg-remove_some_unused_ctrl_id_mappings.patch to
  successfully build against libvpx >= 1.5 (at least on PMBS).
* Thu Dec 17 2015 olaf@aepfle.de
- Add buildconditionals for libass,libva,vdpau to fix build in SLE_11
* Mon Dec 14 2015 olaf@aepfle.de
- Rename bcond dca to dcadec
- Add more buildconditionals to get closer to removal of BUILD_ORIG
* Wed Dec  9 2015 olaf@aepfle.de
- Remove unused imlib2
* Mon Dec  7 2015 idonmez@suse.com
- Sync with packman changes
  * All packman specific changes are protected with BUILD_ORIG
- Added the following patches
  * ffmpeg-2.4.5-arm6l.patch
  * ffmpeg-libcdio_cdda-pkgconfig.patch
* Sun Nov 29 2015 jengelh@inai.de
- Update to new upstream maintenance release 2.8.3
  * avformat/matroskadec: Check subtitle stream before dereferencing
  * avcodec/jpeg2000dec: Fix potential integer overflow with tile
  dimensions
  * avcodec/jpeg2000dec: Check for duplicate SIZ marker
  * avcodec/jpeg2000: Change coord to 32bit to support larger than
  32k width or height
  * avcodec/jpeg2000dec: Check SIZ dimensions to be within the
  supported range
  * avcodec/jpeg2000: Check comp coords to be within the supported
  size
  * dds: validate compressed source buffer size
  * dds: validate source buffer size before copying
  * softfloat: assert when the argument of av_sqrt_sf is negative
- Fixes CVE-2015-8363 [bnc#957114], CVE-2015-8364 [bnc#957115],
  CVE-2015-8365 [bnc#957116]
* Sat Nov 14 2015 idonmez@suse.com
- Update to new upstream release 2.8.2, containing fixes for the
  following security issues:
  * CVE-2015-8216 boo#955346
  * CVE-2015-8217 boo#955347
  * CVE-2015-8218 boo#955348
  * CVE-2015-8219 boo#955350
- Upstream changes:
  * various fixes in the aac_fixed decoder
  * various fixes in softfloat
  * swresample/resample: increase precision for compensation
  * lavf/mov: add support for sidx fragment indexes
  * avformat/mxfenc: Only store user comment related tags when needed
  * ffmpeg: Don't try and write sdp info if none of the outputs had an rtp format.
  * apng: use correct size for output buffer
  * jvdec: avoid unsigned overflow in comparison
  * avcodec/jpeg2000dec: Clip all tile coordinates
  * avcodec/microdvddec: Check for string end in 'P' case
  * avcodec/dirac_parser: Fix undefined memcpy() use
  * avformat/xmv: Discard remainder of packet on error
  * avformat/xmv: factor return check out of if/else
  * avcodec/mpeg12dec: Do not call show_bits() with invalid bits
  * avcodec/faxcompr: Add missing runs check in decode_uncompressed()
  * libavutil/channel_layout: Check strtol*() for failure
  * avformat/mpegts: Only start probing data streams within probe_packets
  * avcodec/hevc_ps: Check chroma_format_idc
  * avcodec/ffv1dec: Check for 0 quant tables
  * avcodec/mjpegdec: Reinitialize IDCT on BPP changes
  * avcodec/mjpegdec: Check index in ljpeg_decode_yuv_scan() before using it
  * avcodec/h264_slice: Disable slice threads if there are multiple access units in a packet
  * avformat/hls: update cookies on setcookie response
  * opusdec: Don't run vector_fmul_scalar on zero length arrays
  * avcodec/opusdec: Fix extra samples read index
  * avcodec/ffv1: Initialize vlc_state on allocation
  * avcodec/ffv1dec: update progress in case of broken pointer chains
  * avcodec/ffv1dec: Clear slice coordinates if they are invalid or slice header decoding fails for other reasons
  * rtsp: Allow $ as interleaved packet indicator before a complete response header
  * videodsp: don't overread edges in vfix3 emu_edge.
  * avformat/mp3dec: improve junk skipping heuristic
  * concatdec: fix file_start_time calculation regression
  * avcodec: loongson optimize h264dsp idct and loop filter with mmi
  * avcodec/jpeg2000dec: Clear properties in jpeg2000_dec_cleanup() too
  * avformat/hls: add support for EXT-X-MAP
  * avformat/hls: fix segment selection regression on track changes of live streams
  * configure: Require libkvazaar < 0.7.
  * avcodec/vp8: Do not use num_coeff_partitions in thread/buffer setup
- Drop ffmpeg-mov-sidx-fragment.patch, fixed upstream.
* Sat Oct 31 2015 idonmez@suse.com
- Update to new upstream release 2.8.1
  * Minor bugfix release
  * Includes all changes from. Ffmpeg-mt,
    libav master of 2015-08-28, libav 11 as of 2015-08-28
- Add ffmpeg-mov-sidx-fragment.patch to add sidx fragment indexes.
  Needed for new mpv release.
* Wed Sep  9 2015 jengelh@inai.de
- Update to new upstream release 2.8
  * DirectDraw Surface image/texture decoder
  * Many improvements to the JPEG 2000 decoder
  * New video filters: colorkey, SSIM, showvolume, adrawgraph,
  drawgraph, removegrain, erosion, dilation, deflate, inflate,
  reverse, atadenoise, aphasemeter, showfreqs, vectorscope,
  waveform, hstack, vstack, framerate
  * New audio filters: Dynamic Audio Normalizer as dynaudnorm
  filter, areverse, random, deband, sidechaincompress,
  acrossfade
  * allyuv and allrgb video sources
  * Switched default encoders for webm to VP9 and Opus
  * Removed experimental flag from the JPEG 2000 encoder
* Mon Jul 20 2015 jengelh@inai.de
- Update to new upstream release 2.7.2
- webp: fix infinite loop in webp_decode_frame
- huffyuvdec: validate image size
- avcodec/vp8: Check buffer size in vp8_decode_frame_header()
- avcodec/vp8: Fix null pointer dereference in ff_vp8_decode_free()
- avutil/fifo: Fix the case where func() returns less bytes than
  requested in av_fifo_generic_write()
- bytestream2: set the reader to the end when reading more than
  available
- oggparsedirac: check return value of init_get_bits
- vp9/update_prob: prevent out of bounds table read
- avcodec/pngdec: Check values before updating context in
  decode_fctl_chunk()
- avcodec/pngdec: Copy IHDR & plte state from last thread
- avcodec/pngdec: Require a IHDR chunk before fctl
- avcodec/pngdec: Only allow one IHDR chunk
- ffmpeg: Do not use the data/size of a bitstream filter
  after failure
* Thu Jun 25 2015 jengelh@inai.de
- Enable codecs for audio: PCM, Speex, CELT, FLAC, ILBC, Opus
- Enable codecs for image: BMP/PCX/TGA, TIFF, Sun/SGI/X11 raster
  raw Huff-compressed or uncompressed YUV
- Update to new upstream release 2.7.1
  * postproc: fix unaligned access
  * avcodec/flacenc: Fix Invalid Rice order
  * tls_gnutls: fix hang on disconnection
  * avcodec/ffv1enc: fix bps for >8bit yuv when not explicitly set
  * avio: fix potential crashes when combining ffio_ensure_seekback + crc
  * ffmpeg_opt: Check for localtime() failure
  * configure: Disable VSX on unspecified / generic CPUs
* Thu Jun 25 2015 develop7@develop7.info
- Enabled 'bluray' protocol
* Wed Jun 10 2015 jengelh@inai.de
- Update to new upstream release 2.7
  * New encoders: apng (PNG with alpha)
  * New decoders: TDSC (a JPEG/BGR24/zlib format)
  * New audio filters: chorus
  * New video filters: cover_rect, detelecine, fftfilt, find_rect
- Enable codecs: 012v, ansi, apng, bmp, exr, ffv1, ffvhuff
  * unpack DivX-style packed B-frames in MPEG-4 bitstream filter
  * WebM Live Chunk Muxer
  * nvenc level and tier options
- Canopus HQ/HQA decoder
- Automatically rotate videos based on metadata in ffmpeg
- improved Quickdraw compatibility
- VP9 high bit-depth and extended colorspaces decoding support
- WebPAnimEncoder API when available for encoding and muxing WebP
- Direct3D11-accelerated decoding
- Support Secure Transport
- Multipart JPEG demuxer
* Sat May 23 2015 robert.munteanu@gmail.com
- Fix building with BUILD_ORIG
* Sun May 17 2015 jengelh@inai.de
- Update to new upstream release 2.6.3
  * avcodec/libtheoraenc: Check for av_malloc failure
  * ffmpeg_opt: Fix -timestamp parsing
  * avcodec/cavsdec: Use ff_set_dimensions()
  * swr: fix alignment issue caused by 8ch sse functions
  * avcodec/mjpegdec: fix len computation in ff_mjpeg_decode_dqt()
  * avformat/matroskadec: Cleanup error handling for bz2 & zlib
  * avformat/matroskaenc: Check ff_vorbiscomment_length in
  put_flac_codecpriv()
  * avcodec/mpeg12dec: use the correct dimensions for checking SAR
  * xcbgrab: Validate the capture area
  * xcbgrab: Do not assume the non shm image data is always available
  * avfilter/lavfutils: disable frame threads when decoding a single
  image
  * ffmpeg: remove incorrect network deinit
  * OpenCL: Avoid potential buffer overflow in cmdutils_opencl.c
  * libvpxenc: only set noise reduction w/vp8
  * vp9: remove another optimization branch in iadst16 which causes
  overflows.
  * network: Do not leave context locked on error
  * vp9: remove one optimization branch in iadst16 which causes
  overflows.
  * swresample: Allow reinitialization without ever setting channel
  layouts/counts
  * imgutils: initialize palette padding bytes in av_image_alloc
  * id3v2: catch avio_read errors in check_tag
  * avi: Validate sample_size
  * diracdec: avoid overflow of bytes*8 in decode_lowdelay
  * diracdec: prevent overflow in data_unit_size check
  * matroskadec: use uint64_t instead of int for index_scale
  * pngdec: don't use AV_PIX_FMT_MONOBLACK for apng
  * pngdec: return correct error code from decode_frame_common
  * swscale/ppc/swscale_altivec.c: POWER LE support in yuv2planeX_8()
  delete macro GET_VF() it was wrong
  * matroskadec: export cover art correctly
  * mxfenc: don't try to write footer without header
- Enable building avresample for extra API compat
- Remove ffmpeg-pkgconfig-requires.diff: RPM's pkgconfigdeps.sh is
  scanning Requires.private too.
* Mon May 11 2015 dimstar@opensuse.org
- Add baselibs.conf: provide -32bit libraries (used by xine-32bit).
* Mon Apr 13 2015 jengelh@inai.de
- Update to new upstream release 2.6.2
  * avformat/utils: avoid discarded streams in
  av_find_default_stream_index()
  * avutil/cpu: add missing check for mmxext to av_force_cpu_flags
  * avformat/http: replace cookies with updated values instead of
  appending forever
* Thu Mar 19 2015 jengelh@inai.de
- Update to new upstream release 2.6.1
  * Maintenance release with some bugfixes
* Sun Mar  8 2015 jengelh@inai.de
- Update to new upstream release 2.6
  * The VP9 decoder is now usable on x86(-32) and pre-SSSE3 CPUs.
  * 10-bit support in the SPP video filter
  * New video filters: "colorlevels", "tblend", "palettegen",
  "paletteuse". New audio filters: "dcshift".
  * The old libmpcodecs wrapper is finally gone
  * API changes: introduction of device inputs and outputs
* Tue Jan 27 2015 jengelh@inai.de
- Update to new upstream release 2.5.3
  * AVFoundation screen-grabbing support, animated WebP decoding
  support, and Animated PNG support. UDP-Lite support was added.
* Sun Jan  4 2015 jengelh@inai.de
- Initial package (version 2.5.3) for build.opensuse.org
